# Authors

The qtsass project has some great contributors! They are:

- [Andrey Galkin](https://github.com/tmpfork)
- [C.A.M. Gerlach](https://github.com/CAM-Gerlach)
- [Carlos Cordoba](https://github.com/ccordoba12)
- [Dan Bradham](https://github.com/danbradham)
- [Eric Werner](https://github.com/ewerybody)
- [Gonzalo Peña-Castellanos](https://github.com/goanpeca)
- [Matthew Joyce](https://github.com/matsjoyce)
- [Yann Lanthony](https://github.com/yann-lty)


These have been sorted alphabetically.
